@@ -1,5 +1,5 @@
 """
-Copyright (C) 2020 Murilo Marques Marinho (www.murilomarinho.info)
+Copyright (C) 2020-2022 Murilo Marques Marinho (www.murilomarinho.info)
 This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
 License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
 version.
@@ -10,10 +10,11 @@ see <https://www.gnu.org/licenses/>.
 """
 # TODO add the default values here as well
 shared_memory_map = {
-    "dofs": 0,
+    "n_servos": 0,
     "n_potentiometers": 1,
-    "is_open": 2,
-    "port": 3,
-    "port_connect_signal": 4,
-    "shutdown_flag": 5
+    "n_digital_inputs": 2,
+    "is_open": 3,
+    "port": 4,
+    "port_connect_signal": 5,
+    "shutdown_flag": 6
 }
